import time

from flask import request


class RouteLatencyLogger:
    def __init__(self, app=None):
        self.app = app
        self.max_route_latency = None
        if app is not None:
            self.init_app(self.app)

    def init_app(self, app):
        app.before_request(self.before_request)
        app.after_request(self.after_request)
        self.max_route_latency = app.config.get('MAX_ROUTE_LATENCY', None)

    def before_request(self):
        request._start_time = time.time()

    def after_request(self, response):
        if hasattr(request, '_start_time'):
            latency = time.time() - request._start_time
            route = request.endpoint
            if self.max_route_latency is not None and latency > self.max_route_latency:
                self.app.logger.warning(f'High latency for route {route}: {latency:.6f} seconds')
            else:
                self.app.logger.info(f'Latency for route {route}: {latency:.6f} seconds')

        return response


import os
from setuptools import setup


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name="flask-crlatency",
    version="0.0.2",
    author="Prince Roshan",
    author_email="princekrroshan01@gmail.com",
    url="https://github.com/Agent-Hellboy/flask-crlatency",
    description=(
        "A flask extension to log route latency "
    ),
    long_description=read("README.rst"),
    license="MIT",
    nstall_requires=["flask"],
    package_dir={'': 'src'},
    packages=['flask_crlatency'],
    keywords=[
        "flask-extension","log-route-latency"
    ],
    python_requires=">=3.8",
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
)